@@ -128,7 +128,7 @@ ee_get_date_ic <- function(x, time_end = FALSE) {
 
 
   if (is.null(time_start)) {
-    time_start <- NA
+    time_start <- rep(NA, length(image_id))
   } else {
     time_start <- as.POSIXct(
       x = time_start / 1000,
@@ -207,7 +207,13 @@ ee_get_earthengine_path <- function() {
       "run rgee::ee_Initialize() to fixed."
     )
   }
-  return(sprintf("%s/%s/", ee_path, user))
+
+  if (user == "ndef") {
+    ee_path
+  } else {
+    sprintf("%s/%s/", ee_path, user)
+  }
+
 }
 
 
